tlslite.errors.TLSAbruptCloseError

Package tlslite :: Module errors :: Class TLSAbruptCloseError |
[hide private]
[frames] | no frames]

# Class TLSAbruptCloseError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            TLSError --+
                                       |
                                      TLSAbruptCloseError

The socket was closed without a proper TLS shutdown.

The TLS specification mandates that an alert of some sort must be sent before the underlying socket is closed. If the socket is closed without this, it could signify that an attacker is trying to truncate the connection. It could also signify a misbehaving TLS implementation, or a random network failure.

Instance Methods | [hide private]
Inherited from `TLSError`: `__str__` Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`